pub fn checksum<T>(data: &[u8]) -> TExpand description
Type agonostic wrapping checksum function. We typically only use the u32 version, as u16 and u8 values are the same, with the top bytes masked off.
pub fn checksum<T>(data: &[u8]) -> TType agonostic wrapping checksum function. We typically only use the u32 version, as u16 and u8 values are the same, with the top bytes masked off.