identify_rom

Function identify_rom 

pub fn identify_rom(
    rom_type: &RomType,
    _sum: u32,
    sha1: [u8; 20],
) -> (Vec<&'static RomEntry>, Vec<(&'static RomEntry, RomType)>)
Function to identify a ROM by SHA1. We do not do checksum matching at all because clashes are likely, and it complicates our logic (we have to only do checksum matching if SHA1 fails for all ROM types).

Returns a tuple of matching ROM entries and those that matched, but with the wrong type. These “bad” matches are likely due to chip select line differences between the ROM tested and the information in the database.