Module types

Module types 

One ROM Database - Types

Enums

CsActive
Whether a CS line is active low or active high
CsActiveByte
RomType
Supported types of ROMs. This type includes the chip select behaviour of the ROM, which was mask programmed at factory for the original ROM chips.
RomTypeByte