RomType

Enum RomType 

pub enum RomType {
    Type27512,
    Type23128 {
        cs1: CsActive,
        cs2: CsActive,
        cs3: CsActive,
    },
    Type2364 {
        cs: CsActive,
    },
    Type2332 {
        cs1: CsActive,
        cs2: CsActive,
    },
    Type2316 {
        cs1: CsActive,
        cs2: CsActive,
        cs3: CsActive,
    },
}
Supported types of ROMs. This type includes the chip select behaviour of the ROM, which was mask programmed at factory for the original ROM chips.

Variants



Type27512

A 27512 ROM



Type23128

A 23128 ROM

Fields



Type2364

A 2364 ROM

Fields



Type2332

A 2332 ROM

Fields



Type2316

A 2316 ROM

Fields

Implementations

Source

impl RomType

pub const fn max_size() -> usize

Returns the max size of ROM supported by this object.

pub const fn size(&self) -> usize

Returns the size of this ROM.

pub const fn rom_pins(&self) -> usize

Returns number of pins this ROM type has

pub const fn invalid_addr_lines(&self) -> &'static [u8]

pub fn cs_active_mask(&self) -> usize

Returns the active CS mask for this ROM type.

pub const fn all() -> &'static [RomType]

Returns all supported ROM types.

pub const fn type_str(&self) -> &'static str

pub const fn cs_str(&self) -> &'static str

pub const fn binary_size() -> usize

Retrieves the binary size of this structure when binary serialized.

pub fn from_bytes(buf: &[u8]) -> Result<Self, Error>

Format is RomTypeByte followed by up to 3 CsActiveByte values.

pub fn to_bytes(&self, buf: &mut [u8]) -> Result<(), Error>

Serializes this structure into the given buffer.