pub enum RomType {
Type2364 {
cs: CsActive,
},
Type2332 {
cs1: CsActive,
cs2: CsActive,
},
Type2316 {
cs1: CsActive,
cs2: CsActive,
cs3: CsActive,
},
}Expand description
Supported types of ROMs. This type includes the chip select behaviour of the ROM, which was mask programmed at factory for the original ROM chips.
Variants
Implementations
Sourceimpl RomType
impl RomType
Sourcepub fn cs_active_mask(&self) -> usize
pub fn cs_active_mask(&self) -> usize
Returns the active CS mask for this ROM type.
pub const fn type_str(&self) -> &'static str
pub const fn cs_str(&self) -> &'static str
Sourcepub const fn binary_size() -> usize
pub const fn binary_size() -> usize
Retrieves the binary size of this structure when binary serialized.
Sourcepub fn from_bytes(buf: &[u8]) -> Result<Self, Error>
pub fn from_bytes(buf: &[u8]) -> Result<Self, Error>
Format is RomTypeByte followed by up to 3 CsActiveByte values.